pyglet.image
============

.. rubric:: Submodules

.. toctree::
   :maxdepth: 1

   atlas
   animation
   buffer

.. rubric:: Details

.. automodule:: pyglet.image

Classes
-------

Images
^^^^^^

.. autoclass:: AbstractImage
  :members:
  :undoc-members:

.. autoclass:: BufferImage
  :members:
  :undoc-members:
  :show-inheritance:

.. autoclass:: BufferImageMask
  :members:
  :undoc-members:
  :show-inheritance:

.. autoclass:: ColorBufferImage
  :members:
  :undoc-members:
  :show-inheritance:

.. autoclass:: DepthBufferImage
  :members:
  :undoc-members:
  :show-inheritance:

.. autoclass:: Texture
  :members:
  :undoc-members:
  :show-inheritance:

.. autoclass:: TextureRegion
  :members:
  :undoc-members:
  :show-inheritance:

.. autoclass:: TileableTexture
  :members:
  :undoc-members:
  :show-inheritance:

Image Sequences
^^^^^^^^^^^^^^^

.. autoclass:: AbstractImageSequence
  :members:
  :undoc-members:

.. autoclass:: TextureSequence
  :members:
  :undoc-members:
  :show-inheritance:

.. autoclass:: UniformTextureSequence
  :members:
  :undoc-members:
  :show-inheritance:

.. autoclass:: TextureGrid
  :members:
  :undoc-members:
  :show-inheritance:

.. autoclass:: Texture3D
  :members:
  :undoc-members:
  :show-inheritance:

Patterns
^^^^^^^^

.. autoclass:: ImagePattern
  :members:
  :undoc-members:

.. autoclass:: CheckerImagePattern
  :members:
  :undoc-members:
  :show-inheritance:

.. autoclass:: SolidColorImagePattern
  :members:
  :undoc-members:
  :show-inheritance:

Data
^^^^

.. autoclass:: ImageData
  :members:
  :undoc-members:
  :show-inheritance:

.. autoclass:: CompressedImageData
  :members:
  :undoc-members:
  :show-inheritance:

.. autoclass:: ImageDataRegion
  :members:
  :undoc-members:
  :show-inheritance:

Other Classes
^^^^^^^^^^^^^

.. autoclass:: BufferManager
  :members:
  :undoc-members:

.. autoclass:: ImageGrid
  :members:
  :undoc-members:
  :show-inheritance:

Functions
---------

.. autofunction:: create
.. autofunction:: get_buffer_manager
.. autofunction:: load
.. autofunction:: load_animation
.. autofunction:: get_max_texture_size

Exceptions
----------

.. autoclass:: ImageException
.. autoclass:: pyglet.image.codecs.ImageEncodeException
.. autoclass:: pyglet.image.codecs.ImageDecodeException
